summaryrefslogtreecommitdiffstats
path: root/content
diff options
context:
space:
mode:
authorcevans@chromium.org <cevans@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-05 01:35:58 +0000
committercevans@chromium.org <cevans@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-05 01:35:58 +0000
commitac8bd041b81e46e4e4fcd5021aaa5499703952e6 (patch)
tree8e3721172fec907d6a0905fca18cb08a91cae3a0 /content
parenta0461055bead3cb4904fec723e4145b629db4360 (diff)
downloadchromium_src-ac8bd041b81e46e4e4fcd5021aaa5499703952e6.zip
chromium_src-ac8bd041b81e46e4e4fcd5021aaa5499703952e6.tar.gz
chromium_src-ac8bd041b81e46e4e4fcd5021aaa5499703952e6.tar.bz2
Follow-on fixes and naming changes for https://codereview.chromium.org/12086077/
BUG=172573 Review URL: https://codereview.chromium.org/12177018 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@180600 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content')
-rw-r--r--content/browser/plugin_service_impl.cc12
-rw-r--r--content/browser/plugin_service_impl_browsertest.cc2
-rw-r--r--content/browser/renderer_host/render_message_filter.cc12
-rw-r--r--content/public/browser/plugin_service_filter.h18
4 files changed, 22 insertions, 22 deletions
diff --git a/content/browser/plugin_service_impl.cc b/content/browser/plugin_service_impl.cc
index 101fcf4..7079828 100644
--- a/content/browser/plugin_service_impl.cc
+++ b/content/browser/plugin_service_impl.cc
@@ -489,12 +489,12 @@ bool PluginServiceImpl::GetPluginInfo(int render_process_id,
*is_stale = stale;
for (size_t i = 0; i < plugins.size(); ++i) {
- if (!filter_ || filter_->IsPluginEnabled(render_process_id,
- render_view_id,
- context,
- url,
- page_url,
- &plugins[i])) {
+ if (!filter_ || filter_->IsPluginAvailable(render_process_id,
+ render_view_id,
+ context,
+ url,
+ page_url,
+ &plugins[i])) {
*info = plugins[i];
if (actual_mime_type)
*actual_mime_type = mime_types[i];
diff --git a/content/browser/plugin_service_impl_browsertest.cc b/content/browser/plugin_service_impl_browsertest.cc
index 0f25185..94b929a 100644
--- a/content/browser/plugin_service_impl_browsertest.cc
+++ b/content/browser/plugin_service_impl_browsertest.cc
@@ -121,7 +121,7 @@ class MockPluginServiceFilter : public content::PluginServiceFilter {
public:
MockPluginServiceFilter() {}
- virtual bool IsPluginEnabled(
+ virtual bool IsPluginAvailable(
int render_process_id,
int render_view_id,
const void* context,
diff --git a/content/browser/renderer_host/render_message_filter.cc b/content/browser/renderer_host/render_message_filter.cc
index cd202d6..9bd597b 100644
--- a/content/browser/renderer_host/render_message_filter.cc
+++ b/content/browser/renderer_host/render_message_filter.cc
@@ -673,12 +673,12 @@ void RenderMessageFilter::GetPluginsCallback(
for (size_t i = 0; i < all_plugins.size(); ++i) {
// Copy because the filter can mutate.
webkit::WebPluginInfo plugin(all_plugins[i]);
- if (!filter || filter->IsPluginEnabled(child_process_id,
- routing_id,
- resource_context_,
- GURL(),
- GURL(),
- &plugin)) {
+ if (!filter || filter->IsPluginAvailable(child_process_id,
+ routing_id,
+ resource_context_,
+ GURL(),
+ GURL(),
+ &plugin)) {
plugins.push_back(plugin);
}
}
diff --git a/content/public/browser/plugin_service_filter.h b/content/public/browser/plugin_service_filter.h
index 6b64818..f0b8bbc 100644
--- a/content/public/browser/plugin_service_filter.h
+++ b/content/public/browser/plugin_service_filter.h
@@ -20,16 +20,16 @@ class PluginServiceFilter {
public:
virtual ~PluginServiceFilter() {}
// Whether |plugin| is enabled. The client can return false to hide the
// plugin, or return true and optionally change the passed in plugin.
- virtual bool IsPluginEnabled(int render_process_id,
- int render_view_id,
- const void* context,
- const GURL& url,
- const GURL& policy_url,
- webkit::WebPluginInfo* plugin) = 0;
-
- // Whether the renderer has permission to load enabled |plugin|.
+ virtual bool IsPluginAvailable(int render_process_id,
+ int render_view_id,
+ const void* context,
+ const GURL& url,
+ const GURL& policy_url,
+ webkit::WebPluginInfo* plugin) = 0;
+
+ // Whether the renderer has permission to load available |plugin|.
virtual bool CanLoadPlugin(int render_process_id,
const FilePath& path) = 0;
};
@@ -20,16 +20,16 @@ class PluginServiceFilter {
public:
virtual ~PluginServiceFilter() {}
- // Whether |plugin| is enabled. The client can return false to hide the
+ // Whether |plugin| is available. The client can return false to hide the
// plugin, or return true and optionally change the passed in plugin.